
#ifndef KUSERFEEDBACKWIDGETS_EXPORT_H
#define KUSERFEEDBACKWIDGETS_EXPORT_H

#ifdef KUSERFEEDBACKWIDGETS_STATIC_DEFINE
#  define KUSERFEEDBACKWIDGETS_EXPORT
#  define KUSERFEEDBACKWIDGETS_NO_EXPORT
#else
#  ifndef KUSERFEEDBACKWIDGETS_EXPORT
#    ifdef KUserFeedbackWidgets_EXPORTS
        /* We are building this library */
#      define KUSERFEEDBACKWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KUSERFEEDBACKWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KUSERFEEDBACKWIDGETS_NO_EXPORT
#    define KUSERFEEDBACKWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KUSERFEEDBACKWIDGETS_DEPRECATED
#  define KUSERFEEDBACKWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KUSERFEEDBACKWIDGETS_DEPRECATED_EXPORT
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_EXPORT KUSERFEEDBACKWIDGETS_EXPORT KUSERFEEDBACKWIDGETS_DEPRECATED
#endif

#ifndef KUSERFEEDBACKWIDGETS_DEPRECATED_NO_EXPORT
#  define KUSERFEEDBACKWIDGETS_DEPRECATED_NO_EXPORT KUSERFEEDBACKWIDGETS_NO_EXPORT KUSERFEEDBACKWIDGETS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KUSERFEEDBACKWIDGETS_NO_DEPRECATED
#    define KUSERFEEDBACKWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* KUSERFEEDBACKWIDGETS_EXPORT_H */
